==> 0.0.1.tar.gz: android/src/main/java/com/tar2ga/ibox_plugin/IboxLogic.java <==
package com.tar2ga.ibox_plugin;

import android.app.Activity;

import java.util.Hashtable;

import ibox.pro.sdk.external.AttachCardContext;
import ibox.pro.sdk.external.PaymentController;
import ibox.pro.sdk.external.PaymentException;
import ibox.pro.sdk.external.entities.APIAuthResult;
import ibox.pro.sdk.external.entities.Account;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

import static com.tar2ga.ibox_plugin.IboxPlugin.getListener;

public class IboxLogic {
    protected static Activity activity;

    private void enable2can(){
        PaymentController.getInstance().onCreate(activity, null);

        //PaymentController.getInstance().setReaderType(activity, PaymentController.ReaderType.P17, PaymentController.USB_MODE_KEY);
        PaymentController.getInstance().setReaderType(activity, PaymentController.ReaderType.P17, "A4:11:63:8A:7E:AA");
        Hashtable<String, Object> p = new Hashtable<>();
        p.put("NOTUP", true);
        PaymentController.getInstance().setCustomReaderParams(p);

        PaymentController.getInstance().setSingleStepEMV(true);
        PaymentController.getInstance().setRepeatOnError(true);

        PaymentController.getInstance().setPaymentControllerListener(getListener());

        PaymentController.getInstance().enable();
    }

    protected void enable2can(MethodCall call, final MethodChannel.Result result){
        enable2can();

        //result.success(PaymentController.getInstance().isConnected() ? "Connected. \nBattery charge: " + IboxPaymentControllerListener.twoCanChargePercent + "%" : "Disconnected");
        result.success(null);
    }

    protected void auth(MethodCall call, final MethodChannel.Result result) {
        //enable2can();

        String login = call.argument("login");
        String secretKey = call.argument("secretKey");

        login = "Kiox@agent.demo";
        secretKey = "12345678";

//        login = "meb.int@inbox.ru";
//        secretKey = "9630773739";

        //PaymentController.getInstance().setCredentials(login, secretKey);
        //PaymentController.getInstance().setCredentials("meb.int@inbox.ru", "9630773739");
        PaymentController.getInstance().setCredentials(login, secretKey);

        APIAuthResult authResult = PaymentController.getInstance().auth(activity);

        Account account = authResult.getAccount();

        //Gson gson = new Gson();

        //result.success(gson.toJson(account));
        result.success(account.toString());
    }

    protected void attachCard(MethodCall call, final MethodChannel.Result result){
        //enable2can();

        AttachCardContext attachCardContext = new AttachCardContext()
                .setCurrency(PaymentController.Currency.RUB);

        try {
            PaymentController.getInstance().addLinkedCard(activity, attachCardContext);

            result.success(null);
        } catch (PaymentException e) {
            e.printStackTrace();
        }
    }
}

==> 0.0.3.tar.gz: android/src/main/java/com/tar2ga/ibox_plugin/IboxLogic.java <==
package com.tar2ga.ibox_plugin;

import android.app.Activity;

import java.util.Hashtable;

import ibox.pro.sdk.external.AttachCardContext;
import ibox.pro.sdk.external.PaymentController;
import ibox.pro.sdk.external.PaymentException;
import ibox.pro.sdk.external.entities.APIAuthResult;
import ibox.pro.sdk.external.entities.Account;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

import static com.tar2ga.ibox_plugin.IboxPlugin.getListener;

public class IboxLogic {
    protected static Activity activity;

    private void enable2can(){
        PaymentController.getInstance().onCreate(activity, null);

        PaymentController.getInstance().setReaderType(activity, PaymentController.ReaderType.P17, PaymentController.USB_MODE_KEY);
        //PaymentController.getInstance().setReaderType(activity, PaymentController.ReaderType.P17, "A4:11:63:8A:7E:AA");
        Hashtable<String, Object> p = new Hashtable<>();
        p.put("NOTUP", true);
        PaymentController.getInstance().setCustomReaderParams(p);

        PaymentController.getInstance().setSingleStepEMV(true);
        PaymentController.getInstance().setRepeatOnError(true);

        PaymentController.getInstance().setPaymentControllerListener(getListener());

        PaymentController.getInstance().enable();
    }

    protected void enable2can(MethodCall call, final MethodChannel.Result result){
        enable2can();

        //result.success(PaymentController.getInstance().isConnected() ? "Connected. \nBattery charge: " + IboxPaymentControllerListener.twoCanChargePercent + "%" : "Disconnected");
        result.success(null);
    }

    protected void auth(MethodCall call, final MethodChannel.Result result) {
        //enable2can();

        String login = call.argument("login");
        String secretKey = call.argument("secretKey");

        login = "Kiox@agent.demo";
        secretKey = "12345678";

//        login = "meb.int@inbox.ru";
//        secretKey = "9630773739";

        //PaymentController.getInstance().setCredentials(login, secretKey);
        //PaymentController.getInstance().setCredentials("meb.int@inbox.ru", "9630773739");
        PaymentController.getInstance().setCredentials(login, secretKey);

        APIAuthResult authResult = PaymentController.getInstance().auth(activity);

        Account account = authResult.getAccount();

        //Gson gson = new Gson();

        //result.success(gson.toJson(account));
        result.success(account.toString());
    }

    protected void attachCard(MethodCall call, final MethodChannel.Result result){
        //enable2can();

        AttachCardContext attachCardContext = new AttachCardContext()
                .setCurrency(PaymentController.Currency.RUB);

        try {
            PaymentController.getInstance().addLinkedCard(activity, attachCardContext);

            result.success(null);
        } catch (PaymentException e) {
            e.printStackTrace();
        }
    }
}
